import { HttpClient, HttpErrorResponse, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable, Observer } from 'rxjs';
import { environment } from 'src/environments/environment';

declare const PluginHelper: {
  getCsrfToken: Function
  getPluginRestUrl: Function
};

declare const SailPoint: {
  CONTEXT_PATH: string
};


@Injectable({
  providedIn: 'root'
})
export class DataService {
  token: string = '';
  pluginUrl: string = '';
  iiqUrl: string;

  constructor(
    private http : HttpClient,
  ) {
    if (environment.production) {
      this.pluginUrl = PluginHelper.getPluginRestUrl('iiqorgchartplugindemo');
      this.iiqUrl = SailPoint.CONTEXT_PATH;
      this.token = PluginHelper.getCsrfToken();
    } else {
      this.pluginUrl = 'http://192.168.15.129:8080/identityiq/plugin/rest/iiqorgchartplugindemo';
      this.iiqUrl = 'http://192.168.15.129:8080/identityiq';
    }
  }

  private defaultHeaders = () => (
    new HttpHeaders({
      "X-XSRF-TOKEN": this.token,
      "Content-Type": "application/json"
    })
  )

  private defaultHeadersDev = () => (
    new HttpHeaders({
      "Authorization": "Basic $BASE64_CREDENTIAL",
      "Content-Type": "application/json"
    })
  )

  fetchSuggest = (path: string, filter? : any) => {
    return new Observable((observer: Observer<any>) => {
      const url = this.iiqUrl + path;
      let headers;
      if (environment.production) {
        headers = this.defaultHeaders();
      } else {
        headers = this.defaultHeadersDev();
      }

      this.http.post<Request>(url, filter, { headers : headers }).subscribe((res: any) => {
        if (res === null) {
          console.error("Response is null.");
        } 
        if (res['errors'] !== null && res['errors'] !== undefined) {
          console.error(res['errors']);
        }
        if (res['warnings'] !== null && res['warnings'] !== undefined) {
          console.warn(res['warnings']);
        }
        observer.next(res);
        observer.complete();
      })
    });
  }

  fetch = (path: string) => {
    return new Observable((observer: Observer<any>) => {
      const url = this.pluginUrl + path;
      let headers;
      if (environment.production) {
        headers = this.defaultHeaders();
      } else {
        headers = this.defaultHeadersDev();
      }

      this.http.get<Request>(url, { headers : headers }).subscribe((res: any) => {
        if (res === null) {
          console.error("Response is null.");
        } else if (res['statusCodeValue'] && (res.statusCodeValue.toString().startsWith('2') === false) ) {
          if (res.body && res.body.message && res.body.message.length > 0) {
            console.error(res.body.message);
          }
        }
        observer.next(res);
        observer.complete();
      })

    });
  }

}
